@@ -1,21 +1,27 @@
+from __future__ import absolute_import, unicode_literals
+
 from django.conf import settings
 from django.contrib.syndication.views import Feed
-
-from feincms.translations import short_language_code
+from django.utils.translation import get_language
 
 from elephantblog.models import Entry
 
 
-if not hasattr(settings, 'BLOG_TITLE') or not hasattr(settings, 'BLOG_DESCRIPTION'):
+if not (
+        hasattr(settings, 'BLOG_TITLE')
+        and hasattr(settings, 'BLOG_DESCRIPTION')
+):
     import warnings
-    warnings.warn('BLOG_TITLE and/or BLOG_DESCRIPTION not defined in settings.py. Standard values used for the Feed')
+    warnings.warn(
+        'BLOG_TITLE and/or BLOG_DESCRIPTION not defined in'
+        ' settings.py. Standard values used for the Feed')
 
 
 def tryrender(content):
     try:
         return content.render()
-    except TypeError: # Required request argument or something else?
-        return u''
+    except TypeError:  # Required request argument or something else?
+        return ''
 
 
 class EntryFeed(Feed):
@@ -25,7 +31,8 @@ class EntryFeed(Feed):
 
     def items(self):
         if hasattr(Entry, 'translation_of'):
-            return Entry.objects.active().filter(language=short_language_code).order_by('-published_on')[:20]
+            return Entry.objects.active().filter(
+                language=get_language()).order_by('-published_on')[:20]
         else:
             return Entry.objects.active().order_by('-published_on')[:20]
 
@@ -33,7 +40,7 @@ class EntryFeed(Feed):
         return item.title
 
     def item_description(self, item):
-        content = u''.join(tryrender(c) for c in item.content.main)
+        content = ''.join(tryrender(c) for c in item.content.main)
         return content
 
     def item_pubdate(self, item):
